summaryrefslogtreecommitdiffstats
path: root/test/vol.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/vol.c')
-rw-r--r--test/vol.c82
1 files changed, 54 insertions, 28 deletions
diff --git a/test/vol.c b/test/vol.c
index 0ef84c5..553a9cf 100644
--- a/test/vol.c
+++ b/test/vol.c
@@ -43,11 +43,17 @@ static const H5VL_class_t fake_vol_g = {
0, /* version */
(H5VL_class_value_t)999, /* value */
FAKE_VOL_NAME, /* name */
+ 0, /* capability flags */
NULL, /* initialize */
NULL, /* terminate */
- (size_t)0, /* fapl size */
- NULL, /* fapl copy */
- NULL, /* fapl free */
+ (size_t)0, /* info size */
+ NULL, /* info copy */
+ NULL, /* info compare */
+ NULL, /* info free */
+ NULL, /* get_object */
+ NULL, /* get_wrap_ctx */
+ NULL, /* free_wrap_ctx */
+ NULL, /* wrap_object */
{ /* attribute_cls */
NULL, /* create */
NULL, /* open */
@@ -120,7 +126,7 @@ static const H5VL_class_t fake_vol_g = {
* Function: test_vol_registration()
*
* Purpose: Tests if we can load, register, and close a simple
- * VOL driver.
+ * VOL plugin.
*
* Return: SUCCEED/FAIL
*
@@ -130,28 +136,48 @@ static herr_t
test_vol_registration(void)
{
htri_t is_registered;
- hid_t vol_id = -1;
+ hid_t vol_id = -1, vol_id2 = -1;
TESTING("VOL registration");
- /* The test/fake VOL driver should not be registered at the start of the test */
- if ((is_registered = H5VLis_driver_registered(FAKE_VOL_NAME)) < 0)
+ /* The test/fake VOL plugin should not be registered at the start of the test */
+ if ((is_registered = H5VLis_plugin_registered(FAKE_VOL_NAME)) < 0)
FAIL_STACK_ERROR;
if (is_registered > 0)
- FAIL_PUTS_ERROR("native VOL driver is inappropriately registered");
+ FAIL_PUTS_ERROR("native VOL plugin is inappropriately registered");
/* Load a VOL interface */
- if ((vol_id = H5VLregister_driver(&fake_vol_g)) < 0)
+ if ((vol_id = H5VLregister_plugin(&fake_vol_g)) < 0)
FAIL_STACK_ERROR;
- /* The test/fake VOL driver should be registered now */
- if ((is_registered = H5VLis_driver_registered(FAKE_VOL_NAME)) < 0)
+ /* The test/fake VOL plugin should be registered now */
+ if ((is_registered = H5VLis_plugin_registered(FAKE_VOL_NAME)) < 0)
FAIL_STACK_ERROR;
if (0 == is_registered)
- FAIL_PUTS_ERROR("native VOL driver is un-registered");
+ FAIL_PUTS_ERROR("native VOL plugin is un-registered");
- /* Close the VOL interface */
- if (H5VLclose(vol_id) < 0)
+ /* Re-register a VOL plugin */
+ if ((vol_id2 = H5VLregister(&fake_vol_g, H5P_DEFAULT)) < 0)
+ FAIL_STACK_ERROR;
+
+ /* The test/fake VOL plugin should still be registered now */
+ if ((is_registered = H5VLis_registered(FAKE_VOL_NAME)) < 0)
+ FAIL_STACK_ERROR;
+ if (0 == is_registered)
+ FAIL_PUTS_ERROR("native VOL plugin is un-registered");
+
+ /* Unregister the second test/fake VOL ID */
+ if (H5VLunregister(vol_id2) < 0)
+ FAIL_STACK_ERROR;
+
+ /* The test/fake VOL plugin should still be registered now */
+ if ((is_registered = H5VLis_registered(FAKE_VOL_NAME)) < 0)
+ FAIL_STACK_ERROR;
+ if (0 == is_registered)
+ FAIL_PUTS_ERROR("native VOL plugin is un-registered");
+
+ /* Unregister the original test/fake VOL ID */
+ if (H5VLunregister(vol_id) < 0)
FAIL_STACK_ERROR;
PASSED();
@@ -159,7 +185,7 @@ test_vol_registration(void)
error:
H5E_BEGIN_TRY {
- H5VLclose(vol_id);
+ H5VLunregister(vol_id);
} H5E_END_TRY;
return FAIL;
@@ -169,7 +195,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_native_vol_init()
*
* Purpose: Tests if the native VOL driver gets initialized.
*
* Return: SUCCEED/FAIL
*
@@ -180,13 +206,13 @@ test_native_vol_init(void)
{
htri_t is_registered;
- TESTING("Native VOL driver initialization");
+ TESTING("Native VOL plugin initialization");
- /* The native VOL driver should always be registered */
- if ((is_registered = H5VLis_driver_registered(H5VL_NATIVE_NAME)) < 0)
+ /* The native VOL plugin should always be registered */
+ if ((is_registered = H5VLis_plugin_registered(H5VL_NATIVE_NAME)) < 0)
FAIL_STACK_ERROR;
if (0 == is_registered)
- FAIL_PUTS_ERROR("native VOL driver is un-registered");
+ FAIL_PUTS_ERROR("native VOL plugin is un-registered");
PASSED();
return SUCCEED;
@@ -200,7 +226,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_file_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL file operations
*
* Return: SUCCEED/FAIL
*
@@ -321,7 +347,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_group_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL group operations
*
* Return: SUCCEED/FAIL
*
@@ -412,7 +438,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_dataset_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL dataset operations
*
* Return: SUCCEED/FAIL
*
@@ -581,7 +607,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_attribute_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL attribute operations
*
* Return: SUCCEED/FAIL
*
@@ -679,7 +705,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_object_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL object operations
*
* Return: SUCCEED/FAIL
*
@@ -743,7 +769,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_link_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL link operations
*
* Return: SUCCEED/FAIL
*
@@ -808,7 +834,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_basic_datatype_operation()
*
* Purpose: Uses the native VOL driver to test basic VOL datatype operations
*
* Return: SUCCEED/FAIL
*
@@ -890,7 +916,7 @@ error:
/*-------------------------------------------------------------------------
* Function: test_echo_vol_operation()
*
* Purpose: Uses the echo VOL driver to test basic VOL operations
* via the H5VL public API.
*
* Return: SUCCEED/FAIL
@@ -169,7 +195,7 @@ error:
* Function: test_native_vol_init()
*
- * Purpose: Tests if the native VOL driver gets initialized.
+ * Purpose: Tests if the native VOL plugin gets initialized.
*
* Return: SUCCEED/FAIL
@@ -200,7 +226,7 @@ error:
* Function: test_basic_file_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL file operations
+ * Purpose: Uses the native VOL plugin to test basic VOL file operations
*
* Return: SUCCEED/FAIL
@@ -321,7 +347,7 @@ error:
* Function: test_basic_group_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL group operations
+ * Purpose: Uses the native VOL plugin to test basic VOL group operations
*
* Return: SUCCEED/FAIL
@@ -412,7 +438,7 @@ error:
* Function: test_basic_dataset_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL dataset operations
+ * Purpose: Uses the native VOL plugin to test basic VOL dataset operations
*
* Return: SUCCEED/FAIL
@@ -581,7 +607,7 @@ error:
* Function: test_basic_attribute_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL attribute operations
+ * Purpose: Uses the native VOL plugin to test basic VOL attribute operations
*
* Return: SUCCEED/FAIL
@@ -679,7 +705,7 @@ error:
* Function: test_basic_object_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL object operations
+ * Purpose: Uses the native VOL plugin to test basic VOL object operations
*
* Return: SUCCEED/FAIL
@@ -743,7 +769,7 @@ error:
* Function: test_basic_link_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL link operations
+ * Purpose: Uses the native VOL plugin to test basic VOL link operations
*
* Return: SUCCEED/FAIL
@@ -808,7 +834,7 @@ error:
* Function: test_basic_datatype_operation()
*
- * Purpose: Uses the native VOL driver to test basic VOL datatype operations
+ * Purpose: Uses the native VOL plugin to test basic VOL datatype operations
*
* Return: SUCCEED/FAIL
@@ -890,7 +916,7 @@ error:
* Function: test_echo_vol_operation()
*
- * Purpose: Uses the echo VOL driver to test basic VOL operations
+ * Purpose: Uses the echo VOL plugin to test basic VOL operations
* via the H5VL public API.
*